==> pytoughreact-0.0.13-py3-none-any.whl: pytoughreact/constants/plotconstants.py <==
'''
MIT License

Copyright (c) [2022] [Temitope Ajayi]

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.

'''

#directions
BOTTOM = 'bottom'
LEFT = 'left'
RIGHT = 'right'
TOP = 'top'

#Periods
YEAR = 'year'
X_LABEL_TIME_YEAR = 'Time (year)'
DAY = 'day'
X_LABEL_TIME_DAY = 'Time (day)'
HOUR = 'hour'
X_LABEL_TIME_HOUR = 'Time (hour)'
MINUTE = 'min'
X_LABEL_TIME_MINUTE = 'Time (min)'
TIME_CAPS = 'Time'
TIME = 'time'

#Multi labels
MULTI_PLOT_DESCRIPTION_LABEL = 'Multi plot' + ' vs ' + 'time' + '.png'
MULTI_PLOT_EXPERIMENT_RESTART_LABEL = 'Multi plot' + ' vs ' + 'experiment restart time' + '.png'
MULTI_PLOTS_PER_PANEL =  ' Multi_Plot_Per_Panel'
MULTIPLE_PARAM = 'multiple param'
MULTIPLE_PARAM_OUTPUT = 'multiple param OUTPUT'


#Plot method parameters
HORIZONTAL = 'horizontal'
VERTICAL = 'vertical'
MY_STYLE = 'mystyle'
CLASSIC = 'classic'
TIGHT_BBOX = 'tight'
LOC_BEST = 'best'
LOC_LOWER_CENTER = 'lower center'
PLAIN_STYLE = 'plain'
BOTH = 'both'
MAJOR = 'major'
MINOR = 'minor'
CMAP_COLOR = 'coolwarm'
IMAGE_TYPE = '.png'
METHOD = 'nearest'
INTERPOLATION = 'none'
ASPECT = 'auto'

# Added plot parameters
RESULT = 'result'
MASS_FRACTION = 'Mass Fraction'
DIFFERENT_FILES_TAG = 'for different files'
PROPERTY = 'property'
FILE = 'file'
VERSUS = 'vs'
EXPERIMENT = 'experiment'
RESTART = 'restart'
DISTANCE_MSG = 'Distance in the'
DIRECTION = 'direction'
DISTANCE = 'distance'
METER = 'm'
HORIZONTAL_ADDED = 'horizontal'
VERTICAL_ADDED = 'vertical'
DEPTH = 'depth'
LAYER_FOR_LAYER = 'layer plot for layer'

#Symbols
COLOR_FORMAT = '--or'
ALL_MARKERS = ["o", "v", "^", "<", ">", "1", "2", "3", "4", "8", "s", "p", "P", "*", "h", "H", "+", "x", "X", "D","d", "|", "_"]
ALL_COLORS = ['r', 'royalblue', 'g', 'k', 'c', 'm', 'y']
X = 'x'
Y = 'y'
X_CAPS = 'X'
Z_CAPS = 'Z'
CARET_SYMBOL = '^'
K_COLOR = 'k'
RED_SYMBOL = '--r'
RED_COLOR = 'r'
OPEN_BRACKET = '('
CLOSE_BRACKET = ')'

==> pytoughreact-1.0.4-py3-none-any.whl: pytoughreact/constants/plotconstants.py <==
'''
MIT License

Copyright (c) [2022] [Temitope Ajayi]

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.

'''

# directions
BOTTOM = 'bottom'
LEFT = 'left'
RIGHT = 'right'
TOP = 'top'

# Periods
YEAR = 'year'
X_LABEL_TIME_YEAR = 'Time (year)'
DAY = 'day'
X_LABEL_TIME_DAY = 'Time (day)'
HOUR = 'hour'
X_LABEL_TIME_HOUR = 'Time (hour)'
MINUTE = 'min'
X_LABEL_TIME_MINUTE = 'Time (min)'
TIME_CAPS = 'Time'
TIME = 'time'

# Multi labels
MULTI_PLOT_DESCRIPTION_LABEL = 'Multi plot' + ' vs ' + 'time' + '.png'
MULTI_PLOT_EXPERIMENT_RESTART_LABEL = 'Multi plot' + ' vs ' + 'experiment restart time' + '.png'
MULTI_PLOTS_PER_PANEL = ' Multi_Plot_Per_Panel'
MULTIPLE_PARAM = 'multiple param'
MULTIPLE_PARAM_OUTPUT = 'multiple param OUTPUT'


# Plot method parameters
HORIZONTAL = 'horizontal'
VERTICAL = 'vertical'
MY_STYLE = 'mystyle'
CLASSIC = 'classic'
TIGHT_BBOX = 'tight'
LOC_BEST = 'best'
LOC_LOWER_CENTER = 'lower center'
PLAIN_STYLE = 'plain'
BOTH = 'both'
MAJOR = 'major'
MINOR = 'minor'
CMAP_COLOR = 'coolwarm'
IMAGE_TYPE = '.png'
METHOD = 'nearest'
INTERPOLATION = 'none'
ASPECT = 'auto'

# Added plot parameters
RESULT = 'result'
MASS_FRACTION = 'Mass Fraction'
DIFFERENT_FILES_TAG = 'for different files'
PROPERTY = 'property'
FILE = 'file'
VERSUS = 'vs'
EXPERIMENT = 'experiment'
RESTART = 'restart'
DISTANCE_MSG = 'Distance in the'
DIRECTION = 'direction'
DISTANCE = 'distance'
METER = 'm'
HORIZONTAL_ADDED = 'horizontal'
VERTICAL_ADDED = 'vertical'
DEPTH = 'depth'
LAYER_FOR_LAYER = 'layer plot for layer'

# Symbols
COLOR_FORMAT = '--or'
ALL_MARKERS = ["o", "v", "^", "<", ">", "1", "2", "3", "4", "8", "s", "p", "P", "*",
               "h", "H", "+", "x", "X", "D", "d", "|", "_"]
ALL_COLORS = ['r', 'royalblue', 'g', 'k', 'c', 'm', 'y']
X = 'x'
Y = 'y'
X_CAPS = 'X'
Z_CAPS = 'Z'
CARET_SYMBOL = '^'
K_COLOR = 'k'
RED_SYMBOL = '--r'
RED_COLOR = 'r'
OPEN_BRACKET = '('
CLOSE_BRACKET = ')'
